@@ -165,10 +165,10 @@ bool PuzzlePrinter::setupOutputDevices (int leastCellsToFit, int puzzleWidth)
 
     m_light.setColor (QColor("#888888"));
     m_light.setWidth (thin);
-    m_heavy.setColor (QColor(QString("black")));
+    m_heavy.setColor (QColor(QStringLiteral("black")));
     m_heavy.setWidth (thick);
     m_heavy.setCapStyle (Qt::RoundCap);
-    m_dashes.setColor (QColor(QString("black")));
+    m_dashes.setColor (QColor(QStringLiteral("black")));
     m_dashes.setWidth (thin);
     m_dashes.setStyle (Qt::DashLine);
 
@@ -404,7 +404,7 @@ void PuzzlePrinter::drawCageLabel (const SKGraph* graph, int n,
 
     QString cLabel = QString::number (graph->cageValue (n));
     if (! killerStyle) {	// No operator is shown in KillerSudoku.
-	cLabel = cLabel + QString(" /-x+").mid(graph->cageOperator (n), 1);
+	cLabel = cLabel + QStringLiteral(" /-x+").mid(graph->cageOperator (n), 1);
     }
 
     QFont f = m_p->font();
@@ -412,9 +412,9 @@ void PuzzlePrinter::drawCageLabel (const SKGraph* graph, int n,
     f.setBold (true);
     m_p->setFont(f);
     QFontMetrics fm(f);
-    int w = fm.width(cLabel);
+    int w = fm.boundingRect(cLabel).width();
     int a = fm.ascent();
-    int m = (fm.width(QChar('1'))+1)/3;	// Left margin = 1/3 width of '1'.
+    int m = (fm.boundingRect(QChar('1')).width()+1)/3;	// Left margin = 1/3 width of '1'.
 
     if (killerStyle) {
 	// Cover part of the dashed line, to make a background for the text.
