@@ -25,10 +25,9 @@
 #include "ksudokugame.h"
 #include "settings.h"
 
-#include <qpixmap.h>
-#include <qpainter.h>
+#include <QPainter>
+#include <QPixmap>
 
-#include "ksview.moc"
 
 #include "puzzle.h"
 
