@@ -19,10 +19,12 @@
  ***************************************************************************/
 #include "welcomescreen.h"
 
-#include <KMessageBox>
-
 #include <QDebug>
 
+#include <KConfigGroup>
+#include <KMessageBox>
+#include <KSharedConfig>
+
 #include "ksudokugame.h"
 #include "globals.h"
 #include "puzzle.h"
@@ -59,7 +61,7 @@ WelcomeScreen::WelcomeScreen(QWidget* parent, GameVariantCollection* collection)
 	gameListWidget->setSelectionMode(QAbstractItemView::SingleSelection);
 
 	// Get the previous puzzle configuration.
-	KConfigGroup gameGroup (KGlobal::config(), "KSudokuGame");
+	KConfigGroup gameGroup (KSharedConfig::openConfig(), "KSudokuGame");
 	m_selectedPuzzle = gameGroup.readEntry("SelectedPuzzle", 0);
 	m_difficulty     = gameGroup.readEntry("Difficulty", (int) VeryEasy);
 	m_symmetry       = gameGroup.readEntry("Symmetry"  , (int) CENTRAL);
@@ -70,17 +72,17 @@ WelcomeScreen::WelcomeScreen(QWidget* parent, GameVariantCollection* collection)
 		                   Qt::QueuedConnection,
 				   Q_ARG (int, m_selectedPuzzle));
 
-	connect(gameListWidget->selectionModel(), SIGNAL(currentChanged(QModelIndex,QModelIndex)), this, SLOT(onCurrentVariantChange()));
+	connect(gameListWidget->selectionModel(), &QItemSelectionModel::currentChanged, this, &WelcomeScreen::onCurrentVariantChange);
 	
-	connect(getNewGameButton, SIGNAL(clicked(bool)), this, SLOT(getNewVariant()));
+	connect(getNewGameButton, &QPushButton::clicked, this, &WelcomeScreen::getNewVariant);
 	// TODO disabled due to missing per-game config dialog
 // 	connect(configureGameButton, SIGNAL(clicked(bool)), this, SLOT(configureVariant()));
 	// connect(playGameButton, SIGNAL(clicked(bool)), this, SLOT(playVariant()));			// Disable old create-game code.
 	// connect(gameListWidget, SIGNAL(doubleClicked(QModelIndex)), this, SLOT(playVariant()));	// Disable old create-game code.
 
-	connect(startEmptyButton, SIGNAL(clicked(bool)), this, SLOT(startEmptyGame()));
-	connect(puzzleGeneratorButton, SIGNAL(clicked(bool)), this, SLOT(generatePuzzle()));
-	connect(gameListWidget, SIGNAL(doubleClicked(QModelIndex)), this, SLOT(generatePuzzle()));
+	connect(startEmptyButton, &QPushButton::clicked, this, &WelcomeScreen::startEmptyGame);
+	connect(puzzleGeneratorButton, &QPushButton::clicked, this, &WelcomeScreen::generatePuzzle);
+	connect(gameListWidget, &QListView::doubleClicked, this, &WelcomeScreen::generatePuzzle);
 
 	// GHNS is not implemented yet, so don't show an unuseful button
 	getNewGameButton->hide();
@@ -129,7 +131,7 @@ void WelcomeScreen::onCurrentVariantChange() {
 }
 
 void WelcomeScreen::getNewVariant() {
-	KMessageBox::information(this, i18n("GetNewVariant not implemented"), "");
+	KMessageBox::information(this, i18n("GetNewVariant not implemented"), QLatin1String(""));
 }
 
 void WelcomeScreen::configureVariant() {
@@ -141,10 +143,16 @@ void WelcomeScreen::configureVariant() {
 
 void WelcomeScreen::startEmptyGame() {
 	GameVariant* variant = selectedVariant();
-	if(!variant) return;
+	if(!variant) {
+		KMessageBox::sorry(this, i18n("Please select a puzzle variant."), i18n("Unable to start puzzle"));
+		return;
+	}
 	
 	Game game = variant->startEmpty();
-	if (! game.isValid()) return;
+	if (! game.isValid()) {
+		KMessageBox::sorry(this, i18n("Unable to create an empty puzzle of the chosen variant; please try another."), i18n("Unable to start puzzle"));
+		return;
+	}
 	
 	emit newGameStarted(game, variant);
 }
@@ -152,24 +160,38 @@ void WelcomeScreen::startEmptyGame() {
 void WelcomeScreen::playVariant() {
 	return;		// Disable old game-creation code.
 	GameVariant* variant = selectedVariant();
-	if(!variant) return;
+	if(!variant) {
+		KMessageBox::sorry(this, i18n("Please select a puzzle variant."), i18n("Unable to start puzzle"));
+		return;
+	}
 	
 	Game game = variant->createGame(difficulty(), 0);
+	if(!game.isValid()) {
+		KMessageBox::sorry(this, i18n("Unable to start a puzzle of the chosen variant; please try another."), i18n("Unable to start puzzle"));
+		return;
+	}
 
 	emit newGameStarted(game, variant);
 }
 
 void WelcomeScreen::generatePuzzle() {
 	GameVariant* variant = selectedVariant();
-	if(!variant) return;
+	if(!variant) {
+		KMessageBox::sorry(this, i18n("Please select a puzzle variant."), i18n("Unable to start puzzle"));
+		return;
+	}
 
 	Game game = variant->createGame(difficulty(), symmetry());
+	if(!game.isValid()) {
+		KMessageBox::sorry(this, i18n("Unable to generate a puzzle of the chosen variant; please try another."), i18n("Unable to start puzzle"));
+		return;
+	}
 
 	// Save the selected puzzle configuration.
 	QModelIndex index = gameListWidget->currentIndex();
 	m_selectedPuzzle = index.row();
 
-	KConfigGroup gameGroup (KGlobal::config(), "KSudokuGame");
+	KConfigGroup gameGroup (KSharedConfig::openConfig(), "KSudokuGame");
 	gameGroup.writeEntry("SelectedPuzzle", m_selectedPuzzle);
 	gameGroup.writeEntry("Difficulty", m_difficulty);
 	gameGroup.writeEntry("Symmetry"  , m_symmetry);
@@ -184,4 +206,4 @@ void WelcomeScreen::generatePuzzle() {
 
 }
 
-#include "welcomescreen.moc"
+
